@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """
 <Program Name>
   schema.py
@@ -72,8 +70,8 @@ class Schema:
             self.check_match(object)
         except exceptions.FormatError:
             return False
-        else:
-            return True
+
+        return True
 
     def check_match(self, object):  # pylint: disable=redefined-builtin
         """
