@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """
 <Program Name>
   settings.py
@@ -37,7 +35,3 @@ PBKDF2_ITERATIONS = 100000
 
 # The algorithm(s) in HASH_ALGORITHMS are used to generate key IDs.
 HASH_ALGORITHMS = ["sha256", "sha512"]
-
-# Used in securesystemslib.process, to raise a subprocess.TimeoutExpired if
-# a started subprocess does not terminate before the here specified seconds
-SUBPROCESS_TIMEOUT = 3
