@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """
 <Program Name>
   test_gpg.py
@@ -33,7 +31,6 @@ import cryptography.hazmat.primitives.hashes as hashing
 from cryptography.hazmat import backends
 from cryptography.hazmat.primitives import serialization
 
-from securesystemslib import exceptions, process
 from securesystemslib.formats import ANY_PUBKEY_DICT_SCHEMA, GPG_PUBKEY_SCHEMA
 from securesystemslib.gpg.common import (
     _assign_certified_key_info,
@@ -51,7 +48,6 @@ from securesystemslib.gpg.constants import (
     SHA1,
     SHA256,
     SHA512,
-    gpg_export_pubkey_command,
     have_gpg,
 )
 from securesystemslib.gpg.dsa import create_pubkey as dsa_create_pubkey
@@ -72,10 +68,7 @@ from securesystemslib.gpg.functions import (
 )
 from securesystemslib.gpg.rsa import create_pubkey as rsa_create_pubkey
 from securesystemslib.gpg.util import (
-    Version,
     get_hashing_class,
-    get_version,
-    is_version_fully_supported,
     parse_packet_header,
     parse_subpacket_header,
 )
@@ -100,19 +93,6 @@ class GPGTestUtils:
 class TestUtil(unittest.TestCase):
     """Test util functions."""
 
-    def test_version_utils_return_types(self):
-        """Run dummy tests for coverage."""
-        self.assertTrue(isinstance(get_version(), Version))
-        self.assertTrue(isinstance(is_version_fully_supported(), bool))
-
-    def test_version_utils_error(self):
-        """Run dummy tests for coverage."""
-        with patch(
-            "securesystemslib.gpg.constants.have_gpg", return_value=False
-        ):
-            with self.assertRaises(exceptions.UnsupportedLibraryError):
-                get_version()
-
     def test_get_hashing_class(self):
         # Assert return expected hashing class
         expected_hashing_class = [hashing.SHA1, hashing.SHA256, hashing.SHA512]
@@ -224,25 +204,19 @@ class TestCommon(unittest.TestCase):
         gpg_keyring_path = os.path.join(
             os.path.dirname(os.path.realpath(__file__)), "gpg_keyrings", "rsa"
         )
-        homearg = (
-            "--homedir {}".format(  # pylint: disable=consider-using-f-string
-                gpg_keyring_path
-            ).replace("\\", "/")
-        )
 
-        # Load test raw public key bundle from rsa keyring, used to construct
-        # erroneous gpg data in tests below.
-        keyid = "F557D0FF451DEF45372591429EA70BD13D883381"
-        cmd = gpg_export_pubkey_command(keyid=keyid, homearg=homearg)
-        proc = process.run(cmd, stdout=process.PIPE, stderr=process.PIPE)
-        self.raw_key_data = proc.stdout
-        self.raw_key_bundle = parse_pubkey_bundle(self.raw_key_data)
+        # Load raw public key bundle data from fixtures
+        key = "F557D0FF451DEF45372591429EA70BD13D883381"
+        key_expired = "E8AC80C924116DABB51D4B987CB07D6D2C199C7C"
+        data = {}
+        for keyid in [key, key_expired]:
+            path = os.path.join(gpg_keyring_path, f"{keyid}.raw")
+            with open(path, "rb") as f:
+                data[keyid] = f.read()
 
-        # Export pubkey bundle with expired key for key expiration tests
-        keyid = "E8AC80C924116DABB51D4B987CB07D6D2C199C7C"
-        cmd = gpg_export_pubkey_command(keyid=keyid, homearg=homearg)
-        proc = process.run(cmd, stdout=process.PIPE, stderr=process.PIPE)
-        self.raw_expired_key_bundle = parse_pubkey_bundle(proc.stdout)
+        self.raw_key_data = data[key]
+        self.raw_key_bundle = parse_pubkey_bundle(data[key])
+        self.raw_expired_key_bundle = parse_pubkey_bundle(data[key_expired])
 
     def test_parse_pubkey_payload_errors(self):
         """Test parse_pubkey_payload errors with manually crafted data."""
@@ -609,8 +583,10 @@ class TestGPGRSA(unittest.TestCase):
         )
 
         self.test_dir = os.path.realpath(tempfile.mkdtemp())
-        self.gnupg_home = os.path.join(self.test_dir, "rsa")
-        shutil.copytree(gpg_keyring_path, self.gnupg_home)
+        self.gnupg_home = "rsa"
+        shutil.copytree(
+            gpg_keyring_path, os.path.join(self.test_dir, self.gnupg_home)
+        )
         os.chdir(self.test_dir)
 
     @classmethod
@@ -784,14 +760,14 @@ class TestGPGDSA(unittest.TestCase):
         # Create directory to run the tests without having everything blow up
         self.working_dir = os.getcwd()
         self.test_dir = os.path.realpath(tempfile.mkdtemp())
-        self.gnupg_home = os.path.join(self.test_dir, "dsa")
+        self.gnupg_home = "dsa"
 
         # Find keyrings
         keyrings = os.path.join(
             os.path.dirname(os.path.realpath(__file__)), "gpg_keyrings", "dsa"
         )
 
-        shutil.copytree(keyrings, self.gnupg_home)
+        shutil.copytree(keyrings, os.path.join(self.test_dir, self.gnupg_home))
         os.chdir(self.test_dir)
 
     @classmethod
@@ -883,14 +859,14 @@ class TestGPGEdDSA(unittest.TestCase):
         # Create directory to run the tests without having everything blow up
         self.working_dir = os.getcwd()
         self.test_dir = os.path.realpath(tempfile.mkdtemp())
-        self.gnupg_home = os.path.join(self.test_dir, "dsa")
+        self.gnupg_home = "dsa"
 
         # Find keyrings
         keyrings = os.path.join(
             os.path.dirname(os.path.realpath(__file__)), "gpg_keyrings", "eddsa"
         )
 
-        shutil.copytree(keyrings, self.gnupg_home)
+        shutil.copytree(keyrings, os.path.join(self.test_dir, self.gnupg_home))
         os.chdir(self.test_dir)
 
     @classmethod
@@ -947,32 +923,5 @@ class TestGPGEdDSA(unittest.TestCase):
         self.assertTrue(verify_signature(signature, key, test_data))
 
 
-class TestVersion(unittest.TestCase):
-    """Tests for the Version utility class."""
-
-    def test_version_roundtrip_string(self):
-        """Version parses and formats strings correctly."""
-        for value, expected in [
-            ("1.3.0", Version(1, 3, 0)),
-            ("1.3.1", Version(1, 3, 1)),
-            ("1.3.22", Version(1, 3, 22)),
-        ]:
-            self.assertEqual(Version.from_string(value), expected)
-            self.assertEqual(str(expected), value)
-
-    def test_version_from_string_invalid(self):
-        """Version.from_string rejects invalid inputs."""
-        for value in [
-            "1.3",
-            "1.33.0",
-            "1.3.-1",
-            "1.3.1a",
-        ]:
-            with self.assertRaises(
-                ValueError, msg=f"expected error for input '{value}'"
-            ):
-                Version.from_string(value)
-
-
 if __name__ == "__main__":
     unittest.main()
