@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """
 <Program Name>
   test_interface.py
@@ -197,7 +195,6 @@ class TestInterfaceFunctions(
                 ),
             ]
         ):
-
             with self.assertRaises(
                 ValueError,
                 msg="(row {})".format(  # pylint: disable=consider-using-f-string
@@ -277,13 +274,6 @@ class TestInterfaceFunctions(
                     CryptoError,
                     "Password was not given but private key is encrypted",
                 ),
-                # Error on encrypted but bad pw passed
-                (
-                    [fn_encrypted],
-                    {"password": "bad pw"},
-                    CryptoError,
-                    "Bad decrypt. Incorrect password?",
-                ),
                 # Error on pw and prompt
                 (
                     [fn_default],
@@ -293,7 +283,6 @@ class TestInterfaceFunctions(
                 ),
             ]
         ):
-
             with self.assertRaises(
                 err,
                 msg="(row {})".format(  # pylint: disable=consider-using-f-string
@@ -309,6 +298,18 @@ class TestInterfaceFunctions(
                 ),
             )
 
+        # Error on encrypted but bad pw passed
+        # NOTE: for some key+pw combos the error differs, see pyca/cryptography#8563
+        with self.assertRaises(CryptoError) as ctx:
+            import_rsa_privatekey_from_file(fn_encrypted, password="bad pw")
+
+        error = str(ctx.exception)
+        self.assertTrue(
+            "Bad decrypt. Incorrect password?" in error
+            or "Could not deserialize key data" in error,
+            f"unexpected: {error}",
+        )
+
         # Error on encrypted but bad pw prompted
         err_msg = "Password was not given but private key is encrypted"
         with self.assertRaises(CryptoError) as ctx, mock.patch(
@@ -455,7 +456,6 @@ class TestInterfaceFunctions(
                 ),
             ]
         ):
-
             with self.assertRaises(
                 ValueError,
                 msg="(row {})".format(  # pylint: disable=consider-using-f-string
@@ -564,7 +564,6 @@ class TestInterfaceFunctions(
                 ),
             ]
         ):
-
             with self.assertRaises(
                 err,
                 msg="(row {})".format(  # pylint: disable=consider-using-f-string
@@ -698,7 +697,6 @@ class TestInterfaceFunctions(
                 ),
             ]
         ):
-
             with self.assertRaises(
                 ValueError,
                 msg="(row {})".format(  # pylint: disable=consider-using-f-string
@@ -804,7 +802,6 @@ class TestInterfaceFunctions(
                 ),
             ]
         ):
-
             with self.assertRaises(
                 err,
                 msg="(row {})".format(  # pylint: disable=consider-using-f-string
@@ -856,6 +853,17 @@ class TestInterfaceFunctions(
         """
         key_pw = "pw"
         expected_priv_mode = stat.S_IFREG | stat.S_IRUSR | stat.S_IWUSR
+        if os.name == "nt":
+            expected_priv_mode = (
+                stat.S_IFREG
+                | stat.S_IWUSR
+                | stat.S_IRUSR
+                | stat.S_IWGRP
+                | stat.S_IRGRP
+                | stat.S_IWOTH
+                | stat.S_IROTH
+            )
+
         for idx, (gen, gen_prompt, gen_plain, import_priv, schema) in enumerate(
             [
                 (
@@ -881,7 +889,6 @@ class TestInterfaceFunctions(
                 ),
             ]
         ):
-
             assert_msg = (
                 "(row {})".format(  # pylint: disable=consider-using-f-string
                     idx
@@ -990,7 +997,6 @@ class TestInterfaceFunctions(
                 (self.path_ecdsa, KEY_TYPE_ECDSA, ECDSAKEY_SCHEMA),
             ]
         ):
-
             # Successfully import key per supported type, with ...
             # ... passed password
             key = import_privatekey_from_file(
